import 'package:grpc/grpc.dart';
import 'package:grpc_communication/src/resourcegroup.pb.dart';
import 'package:grpc_communication/src/resourcegroup.pbgrpc.dart';

Future<Map<String, dynamic>> createClient(String host, int port) async {
  final channel = ClientChannel(
    host,
    port: port,
    options: const ChannelOptions(credentials: ChannelCredentials.insecure()),
  );
  final client = DataCenterControlClient(channel);
  return {'client': client, 'channel': channel};
}

Future<CreateGroupResponse> createResourceGroup(String host, int port, String groupName, String location) async {
  final connection = await createClient(host, port);
  final client = connection['client'] as DataCenterControlClient;
  final channel = connection['channel'] as ClientChannel;

  try {
    final request = CreateGroupRequest()
      ..groupName = groupName
      ..location = location;

    return await client.createGroup(request);
  } catch (e) {
    print('Caught error in createGroup: $e');
    rethrow;
  } finally {
    await channel.shutdown();
  }
}

Future<List<ResourceGroup>> fetchResourceGroups(String host, int port) async {
  print('Connecting to $host on port $port');
  final connection = await createClient(host, port);
  final client = connection['client'] as DataCenterControlClient;
  final channel = connection['channel'] as ClientChannel;

  try {
    final response = await client.listResourceGroups(ListResourceGroupsRequest());
    return response.resourceGroups;
  } catch (e) {
    print('Caught error: $e');
    return [];
  } finally {
    await channel.shutdown();
  }
}

